@@ -1,4 +1,3 @@
-import os
 import tomllib
 from collections.abc import Iterable
 from os import PathLike
@@ -44,23 +43,10 @@ def get_src_dir(pyproject_toml_path: str | PathLike | None) -> Path:
         src_directory = Path(
             pyproject["tool"]["setuptools"]["find-directories"]["where"]
         )
-    except KeyError:
+    except KeyError as e:
         src_directory = Path(pyproject_toml_path).parent / "src"
+        if not src_directory.exists():
+            raise KeyError(
+                "Missing key tool.setuptools.find-directories.where in pyproject.toml"
+            ) from e
     return src_directory.resolve()
-
-
-def gen_init_py(src_dir: str | PathLike):
-    """Generate __init__.py files for all subdirectories of src/."""
-    for root, _, files in os.walk(src_dir):
-        if "__init__.py" in files:
-            continue
-        if Path(root).samefile(src_dir):
-            continue
-        if "__pycache__" in root:
-            continue
-        if root.endswith(".egg-info"):
-            continue
-
-        with open(Path(root) / "__init__.py", "w") as f:
-            print("Generating __init__.py in", root)
-            f.write("")
